@@ -29,9 +29,9 @@ class Analytics(BaseHTTPMiddleware):
             'path': request.path,
             'user_agent': request.headers['user-agent'],
             'method': request.method,
-            'status': int(response.status_code),
+            'status': response.status_code,
             'response_time': int(elapsed * 1000),
-            'framework': 'Flask'
+            'framework': 1
         }
         threading.Thread(target=log_request, args=(json,)).start()
         return response
